# AutoGenFiles

Based on a predefined templating structure create new files

## Examples

Check [AutoGenFiles Playground](https://github.com/jtemporal/autogenfiles_playground).

## TODO

There are a few TODO marked on the code but here's a list of most general ones

- [x] guarantee file structure from templates folder
- [ ] test all
- [ ] make it into an installable cli
- [ ] document the variables.yaml structure
- [ ] document how to contribute
- [x] document example with the project in case
- [x] move all logic into an module structure
